@@ -36,6 +36,10 @@ class FirewallCommand(object):
         self.quiet = quiet
         self.verbose = verbose
         self.__use_exception_handler = True
+        self.fw = None
+
+    def set_fw(self, fw):
+        self.fw = fw
 
     def set_quiet(self, flag):
         self.quiet = flag
@@ -51,19 +55,23 @@ class FirewallCommand(object):
 
     def print_msg(self, msg=None):
         if msg is not None and not self.quiet:
-            print(msg)
+            sys.stdout.write(msg + "\n")
+
+    def print_error_msg(self, msg=None):
+        if msg is not None and not self.quiet:
+            sys.stderr.write(msg + "\n")
 
     def print_warning(self, msg=None):
         FAIL = '\033[91m'
         END = '\033[00m'
-        self.print_msg(FAIL + msg + END)
+        self.print_error_msg(FAIL + msg + END)
 
     def print_and_exit(self, msg=None, exit_code=0):
         #OK = '\033[92m'
         FAIL = '\033[91m'
         END = '\033[00m'
         if exit_code > 1:
-            self.print_msg(FAIL + msg + END)
+            self.print_error_msg(FAIL + msg + END)
         else:
             self.print_msg(msg)
             #self.print_msg(OK + msg + END)
@@ -73,16 +81,14 @@ class FirewallCommand(object):
         self.print_and_exit(msg, 2)
 
     def print_if_verbose(self, msg=None):
-        if msg and self.verbose:
-            print(msg)
+        if msg is not None and self.verbose:
+            sys.stdout.write(msg + "\n")
 
     def __cmd_sequence(self, cmd_type, option, action_method, query_method,
                        parse_method, message, start_args=None, end_args=None,
                        no_exit=False):
-        warn_type = {
-            "add": "ALREADY_ENABLED",
-            "remove": "NOT_ENABLED",
-        }
+        if self.fw is not None:
+            self.fw.authorizeAll()
         items = [ ]
         _errors = 0
         for item in option:
@@ -92,45 +98,14 @@ class FirewallCommand(object):
                 except Exception as msg:
                     if len(option) > 1:
                         self.print_warning("Warning: %s" % msg)
+                        _errors += 1
                         continue
                     else:
-                        code = FirewallError.get_code(msg)
+                        code = FirewallError.get_code(str(msg))
                         self.print_and_exit("Error: %s" % msg, code)
+                        _errors += 1
 
-            call_item = [ ]
-            if start_args is not None:
-                call_item += start_args
-            if not isinstance(item, list) and not isinstance(item, tuple):
-                call_item.append(item)
-            else:
-                call_item += item
-            self.deactivate_exception_handler()
-            try:
-                if cmd_type == "add" and not query_method(*call_item):
-                    items.append(item)
-                elif cmd_type == "remove" and query_method(*call_item):
-                    items.append(item)
-                else:
-                    if len(option) > 1:
-                        self.print_warning("Warning: %s: %s" % \
-                                           (warn_type[cmd_type],
-                                            message % item))
-                    else:
-                        code = FirewallError.get_code(warn_type[cmd_type])
-                        self.print_and_exit("Error: %s: %s" % \
-                                            (warn_type[cmd_type],
-                                             message % item), code)
-                    _errors += 1
-            except DBusException as msg:
-                code = FirewallError.get_code(msg)
-                if len(option) > 1:
-                    self.print_warning("Warning: %s" % msg.get_dbus_message())
-                    continue
-                else:
-                    self.print_and_exit("Error: %s" % msg.get_dbus_message(),
-                                        code)
-                _errors += 1
-            self.activate_exception_handler()
+            items.append(item)
 
         for item in items:
             call_item = [ ]
@@ -142,19 +117,41 @@ class FirewallCommand(object):
                 call_item += item
             if end_args is not None:
                 call_item += end_args
+            self.deactivate_exception_handler()
             try:
                 action_method(*call_item)
             except DBusException as msg:
-                code = FirewallError.get_code(msg)
                 if len(option) > 1:
                     self.print_warning("Warning: %s" % msg.get_dbus_message())
                 else:
-                    self.print_and_exit("Error: %s" % msg.get_dbus_message(),
-                                        code)
+                    code = FirewallError.get_code(msg.get_dbus_message())
+                    if code in [ errors.ALREADY_ENABLED, errors.NOT_ENABLED,
+                                 errors.ZONE_ALREADY_SET ]:
+                        self.print_warning("Warning: %s" % \
+                                           msg.get_dbus_message())
+                        sys.exit(0)
+                    else:
+                        self.print_and_exit("Error: %s" % \
+                                            msg.get_dbus_message(), code)
                 _errors += 1
+            except Exception as msg:
+                if len(option) > 1:
+                    self.print_warning("Warning: %s" % msg)
+                    _errors += 1
+                    continue
+                else:
+                    code = FirewallError.get_code(str(msg))
+                    if code in [ errors.ALREADY_ENABLED, errors.NOT_ENABLED,
+                                 errors.ZONE_ALREADY_SET ]:
+                        self.print_warning("Warning: %s" % msg)
+                        sys.exit(0)
+                    else:
+                        self.print_and_exit("Error: %s" % msg, code)
+                    _errors += 1
+            self.activate_exception_handler()
 
         if _errors == len(option) and not no_exit:
-            sys.exit(0)
+            sys.exit(errors.UNKNOWN_ERROR)
 
     def add_sequence(self, option, action_method, query_method, parse_method,
                      message, no_exit=False):
@@ -198,7 +195,7 @@ class FirewallCommand(object):
                         self.print_warning("Warning: %s" % msg)
                         continue
                     else:
-                        code = FirewallError.get_code(msg)
+                        code = FirewallError.get_code(str(msg))
                         self.print_and_exit("Error: %s" % msg, code)
             items.append(item)
 
@@ -214,7 +211,7 @@ class FirewallCommand(object):
             try:
                 res = query_method(*call_item)
             except DBusException as msg:
-                code = FirewallError.get_code(msg)
+                code = FirewallError.get_code(msg.get_dbus_message())
                 if len(option) > 1:
                     self.print_warning("Warning: %s" % msg.get_dbus_message())
                     continue
@@ -448,7 +445,7 @@ class FirewallCommand(object):
     Make sure polkit agent is running or run the application as superuser."""
             self.print_and_exit(msg, errors.NOT_AUTHORIZED)
         else:
-            code = FirewallError.get_code(exception_message)
+            code = FirewallError.get_code(str(exception_message))
             if code in [ errors.ALREADY_ENABLED, errors.NOT_ENABLED,
                          errors.ZONE_ALREADY_SET ]:
                 self.print_warning("Warning: %s" % exception_message)
