@@ -223,7 +223,12 @@ def ipset_reader(filename, path):
     parser.setContentHandler(handler)
     name = "%s/%s" % (path, filename)
     with open(name, "r") as f:
-        parser.parse(f)
+        try:
+            parser.parse(f)
+        except sax.SAXParseException as msg:
+            raise FirewallError(errors.INVALID_IPSET,
+                                "not a valid ipset file: %s" % \
+                                msg.getException())
     del handler
     del parser
     if "timeout" in ipset.options and len(ipset.entries) > 0:
