@@ -10,7 +10,7 @@ readonly RESTORE='\033[0m'
 assert_good() {
   local args="${1}"
 
-  ${path}firewall-cmd ${args} > /dev/null
+  ${path}firewall-cmd ${args} > /dev/null 2>&1
   if [[ "$?" -eq 0 ]]; then
     echo "${args} ... OK"
   else
@@ -23,7 +23,7 @@ assert_good_notempty() {
   local args="${1}"
   local ret
 
-  ret=$(${path}firewall-cmd ${args}) > /dev/null
+  ret=$(${path}firewall-cmd ${args}) > /dev/null 2>&1
   if [[ ( "$?" -eq 0 ) && ( -n "${ret}" ) ]]; then
     echo "${args} ... OK"
   else
@@ -36,7 +36,7 @@ assert_good_empty() {
   local args="${1}"
   local ret
 
-  ret=$(${path}firewall-cmd ${args}) > /dev/null
+  ret=$(${path}firewall-cmd ${args}) > /dev/null 2>&1
   if [[ ( "$?" -eq 0 ) && ( -z "${ret}" ) ]]; then
     echo "${args} ... OK"
   else
@@ -50,7 +50,7 @@ assert_good_equals() {
   local value="${2}"
   local ret
 
-  ret=$(${path}firewall-cmd ${args}) > /dev/null
+  ret=$(${path}firewall-cmd ${args}) > /dev/null 2>&1
   if [[ ( "$?" -eq 0 ) && ( "${ret}" = "${value}" ) ]]; then
     echo "${args} ... OK"
   else
@@ -64,7 +64,7 @@ assert_good_contains() {
   local value="${2}"
   local ret
 
-  ret=$(${path}firewall-cmd ${args}) > /dev/null
+  ret=$(${path}firewall-cmd ${args}) > /dev/null 2>&1
   if [[ ( "$?" -eq 0 ) && ( "${ret}" = *${value}* ) ]]; then
     echo "${args} ... OK"
   else
@@ -90,7 +90,7 @@ assert_bad_contains() {
   local value="${2}"
   local ret
 
-  ret=$(${path}firewall-cmd ${args}) > /dev/null
+  ret=$(${path}firewall-cmd ${args}) > /dev/null 2>&1
   if [[ ( "$?" -ne 0 ) || ( "${ret}" = *${value}* ) ]]; then
     ((failures++))
     echo -e "${args} ... ${RED}${failures}. FAILED (non-zero exit status or '${ret}' does contain '${value}')${RESTORE}"
@@ -115,7 +115,7 @@ assert_rich_good() {
     command="--query-rich-rule"
   fi
 
-  ${path}firewall-cmd ${permanent} ${command} "${args}" > /dev/null
+  ${path}firewall-cmd ${permanent} ${command} "${args}" > /dev/null 2>&1
   if [[ "$?" -eq 0 ]]; then
     echo ${permanent} ${command} "${args} ... OK"
   else
@@ -139,7 +139,7 @@ assert_rich_bad() {
     command="--query-rich-rule"
   fi
 
-  ${path}firewall-cmd ${permanent} ${command} "${args}" > /dev/null
+  ${path}firewall-cmd ${permanent} ${command} "${args}" > /dev/null 2>&1
   if [[ "$?" -ne 0 ]]; then
     echo ${permanent} ${command} "${args} ... OK"
   else
@@ -170,7 +170,7 @@ assert_bad  "--query-panic"
 #assert_good "--lockdown-off"
 #assert_bad  "--query-lockdown"
 
-default_zone=$(${path}firewall-cmd --get-default-zone)
+default_zone=$(${path}firewall-cmd --get-default-zone 2>/dev/null)
 zone="home"
 assert_good_notempty "--get-default-zone"
 assert_good          "--set-default-zone=${zone}"
@@ -577,7 +577,7 @@ assert_bad "--permanent --service=${myservice} --query-destination=ipv6:fd00:dea
 
 # test icmptype options, ipv4 and ipv6 destinations are default
 assert_bad  "--permanent --icmptype=${myicmp} --add-destination=ipv5"
-assert_bad "--permanent --icmptype=${myicmp} --add-destination=ipv4"
+assert_good "--permanent --icmptype=${myicmp} --add-destination=ipv4"
 assert_good "--permanent --icmptype=${myicmp} --remove-destination=ipv4"
 assert_good "--permanent --icmptype=${myicmp} --add-destination=ipv4"
 assert_good "--permanent --icmptype=${myicmp} --query-destination=ipv4"
